@@ -61,8 +61,8 @@ SEXP convhullnew(const SEXP p, const SEXP options)
 	double *pt_array;
 
 
-	FILE *outfile = stdout;      /* output from qh_produce_output() use NULL to skip qh_produce_output() */
-	FILE *errfile = stderr;      /* error messages from qhull code */
+	FILE *outfile = NULL;      /* output from qh_produce_output() use NULL to skip qh_produce_output() */
+	FILE *errfile = NULL;      /* error messages from qhull code */
 
 	retval = R_NilValue;
 
